@@ -14,6 +14,8 @@ from agent.agentClient import AgentClient
 from agent.packages.message.base import CmdContent, TextContent
 from agent.example.config import *
 from agent.example.demoReceiveMessage import DemoReceiveMessage
+from agent.logger import logger
+import logging
 
 
 def message_process_callback(content):
@@ -38,6 +40,8 @@ async def start_agent_client(agent_client):
 
 
 if __name__ == "__main__":
+    f_handler = logging.FileHandler('/tmp/agent.log', encoding='UTF-8')
+    logger.addHandler(f_handler)
     agentClient = AgentClient(websocket_address,
                               websocket_port,
                               websocket_path,
