@@ -94,10 +94,7 @@ class Header(object):
             if header_key['mustInput']:
                 if header_key["key"] in h_keys:
                     key = header_key['key']
-                    if isinstance(self.headerData[key], header_key['type']):
-                        setattr(self, key, self.headerData[key])
-                    else:
-                        raise Exception("%s not %s, please check it" %(header_key['key'], header_key['type']))
+                    setattr(self, key, self.headerData[key])
                 else:
                     raise Exception("%s not exist" % header_key['key'])
         if self.version:
