@@ -27,7 +27,7 @@ class FinishWorkFail(Message):
                 "params": {}
             }
         }
-        super(FinishWorkFail, self).__init__(header, body)
+        super(FinishWorkFail, self).__init__(header, body, agent_client)
 
     def process(self):
         self.agentClient.send_message(self.get_package_string())
